@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc.,  59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
+ * Foundation, Inc.,  51 Franklin Street, Fifth Floor, Cambridge, MA 02139, USA.
  */
 /*
   @NOTATION@
@@ -30,7 +30,7 @@
 #include <unistd.h>
 #include <errno.h>
 
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include <gconf/gconf-client.h>
 #ifndef G_OS_WIN32
@@ -43,7 +43,6 @@
 #include "gnome-exec.h"
 #include "gnome-util.h"
 #include "gnome-init.h"
-#include "gnome-i18n.h"
 #include "gnome-gconfP.h"
 
 #include "gnome-url.h"
@@ -74,32 +73,32 @@ gnome_url_show_with_env (const char  *url,
 	g_return_val_if_fail (url != NULL, FALSE);
 
 	result = gnome_vfs_url_show_with_env (url, envp);
-	
+
 	switch (result) {
 	case GNOME_VFS_OK:
 		return TRUE;
-		
+
 	case GNOME_VFS_ERROR_INTERNAL:
 		g_set_error (error,
 		             GNOME_URL_ERROR,
 			     GNOME_URL_ERROR_VFS,
 			     _("Unknown internal error while displaying this location."));
 		break;
-		
+
 	case GNOME_VFS_ERROR_BAD_PARAMETERS:
 		g_set_error (error,
 			     GNOME_URL_ERROR,
 			     GNOME_URL_ERROR_URL,
 			     _("The specified location is invalid."));
 		break;
-	
+
 	case GNOME_VFS_ERROR_PARSE:
 		g_set_error (error,
 			     GNOME_URL_ERROR,
 			     GNOME_URL_ERROR_PARSE,
 			     _("There was an error parsing the default action command associated "
 			       "with this location."));
-		break;	
+		break;
 
 	case GNOME_VFS_ERROR_LAUNCH:
 		g_set_error (error,
@@ -107,15 +106,15 @@ gnome_url_show_with_env (const char  *url,
 			     GNOME_URL_ERROR_LAUNCH,
 			     _("There was an error launching the default action command associated "
 			       "with this location."));
-		break;	
-	
+		break;
+
 	case GNOME_VFS_ERROR_NO_DEFAULT:
 		g_set_error (error,
 			     GNOME_URL_ERROR,
 			     GNOME_URL_ERROR_NO_DEFAULT,
 			     _("There is no default action associated with this location."));
-		break;	
-	
+		break;
+
 	case GNOME_VFS_ERROR_NOT_SUPPORTED:
 		g_set_error (error,
 			     GNOME_URL_ERROR,
@@ -150,17 +149,24 @@ gnome_url_show_with_env (const char  *url,
 		break;
 
 	case GNOME_VFS_ERROR_INVALID_URI:
+	case GNOME_VFS_ERROR_NOT_FOUND:
 		g_set_error (error,
 		             GNOME_URL_ERROR,
 			     GNOME_URL_ERROR_VFS,
 			     _("The location or file could not be found."));
 		break;
 
-	default:
+	case GNOME_VFS_ERROR_LOGIN_FAILED:
 		g_set_error (error,
 			     GNOME_URL_ERROR,
 			     GNOME_URL_ERROR_VFS,
-			     _("Unknown error code: %u"), result);
+			     _("The login has failed."));
+		break;
+	default:
+		g_set_error_literal (error,
+				     GNOME_URL_ERROR,
+				     GNOME_URL_ERROR_VFS,
+				     gnome_vfs_result_to_string (result));
 	}
 
 	return FALSE;
