@@ -1,6 +1,7 @@
 
-/* Generated data (by glib-mkenums) */
 
+
+#include <config.h>
 #include <glib-object.h>
 #include "libgnometypebuiltins.h"
 
@@ -99,5 +100,5 @@ gnome_url_error_get_type (void)
 }
 
 
-/* Generated data ends here */
+
 
