@@ -8,7 +8,7 @@
  */
 
 #include <config.h>
-#include <bonobo/bonobo-i18n.h>
+#include <glib/gi18n-lib.h>
 #include <bonobo/bonobo-main.h>
 #include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-moniker-util.h>
@@ -36,7 +36,7 @@ bonobo_moniker_conf_indirect_resolve (BonoboMoniker *moniker,
 
 	conf_client = gconf_client_get_default ();
 	oiid = gconf_client_get_string (conf_client, key, &err);
-	g_object_unref (G_OBJECT (conf_client));
+	g_object_unref (conf_client);
 
 	if (!oiid) {
 		bonobo_exception_general_error_set (
@@ -50,6 +50,7 @@ bonobo_moniker_conf_indirect_resolve (BonoboMoniker *moniker,
 	object = bonobo_get_object ((const CORBA_char *) oiid,
 				    requested_interface,
 				    ev);
+	g_free (oiid);
 
 	return object;
 }
